<template>
  <el-main>
    <!--行政处罚决定审批表-->
    <el-form ref="dataForm" :model="dataForm" label-width="110px" :disabled="dataForm.registerState == '1'">
      <el-row>
        <el-col :span="12">
          <el-form-item label="案由">
            <el-input v-model="dataForm.casePoint"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="立案日期">
            <el-date-picker
                v-model="dataForm.caseDate"
                :value-format="`yyyy-MM-dd`"
                type="date"
                placeholder="选择日期"
                style="width: 100%">
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="当事人姓名">
            <el-input v-model="dataForm.litigant"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="法定代表人">
            <el-input v-model="dataForm.legalPerson"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="证件名称">
            <el-select v-model="dataForm.litigantCert" placeholder="请选择证件类型"
                       :disabled="dataForm.registerState == '1'" style="width: 100%;">
              <el-option
                  v-for="item in cardList"
                  :label="item.label"
                  :value="item.value">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="证件号码">
            <el-input v-model="dataForm.certNo"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="住址">
            <el-input v-model="dataForm.address"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="电话">
            <el-input v-model="dataForm.phone"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="依据(执法清单)">
        <el-select
            v-model="dataForm.powerName"
            filterable
            remote
            style="width: 100%"
            :remote-method="querySearchHandle"
            placeholder="请选择执法清单"
            :trigger-on-focus="false"
            @change="handleSelectPower"
        >
          <el-option
              v-for="item in powerList"
              :key="item.id"
              :label="item.projectName"
              :value="item.id">
          </el-option>
        </el-select>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="法律名称">
            <el-select v-model="dataForm.lawName" clearable
                       placeholder="请选择法律" style="width: 100%;" @change="handleSelectLaw">
              <el-option
                  v-for="item in lawList"
                  :key="item.id"
                  :label="item.value"
                  :value="item.id">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="法律条文">
            <el-select v-model="dataForm.lawdetailId" clearable multiple
                       placeholder="请选择法律条文" style="width: 100%;" >
              <el-option
                  v-for="item in lawTiaoList"
                  :key="item.id"
                  :label="item.lawTiaoName"
                  :value="item.id">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="简要案情和处罚内容">
        <el-input type="textarea" v-model="dataForm.casePunish"></el-input>
      </el-form-item>
      <el-form-item label="申辩和听证情况">
        <el-input type="textarea" v-model="dataForm.pleadHear"></el-input>
      </el-form-item>
      <public-opinion ref="publicOpinion" :registerState="dataForm.registerState"></public-opinion>
      <WordView ref="wordInfo" :isShowYulan="showView" @cancel="cancelWord"></WordView>
    </el-form>
    <div style="text-align: center">
      <el-button v-if="dataForm.registerState != '1'" plain @click="dataFormSubmit('0')">保存</el-button>
      <el-button v-if="dataForm.registerState != '1'" type="warning" plain @click="dataFormSubmit('1')">定稿</el-button>
      <el-button type="primary" plain @click="viewVord(dataForm)">预览</el-button>
      <el-button type="success" plain @click="downloadWord(dataForm)">下载</el-button>
    </div>
  </el-main>
</template>

<script>
import {getObj,saveObj} from '@/api/News/administrativePenaltyDecision'
import publicOpinion from "@/views/News/publicOpinion"
import WordView from '@/views/News/word-view/index'
import moment from "moment";
import {remote} from "@/api/admin/dict"
import {getLawByPowerId, getPowerList} from "@/api/lawList/lawList";

export default {
  name: "administrative_penalty_decision",
  props: ['isShowYulan', 'id', 'processId','title'],
  components: {
    publicOpinion,
    WordView
  },
  data() {
    return {
      showView: false,
      dataForm: {
        casePoint: '',
        caseDate: '',
        litigant: '',
        legalPerson: '',
        litigantCert: '',
        certNo: '',
        address: '',
        phone: '',
        casePunish: '',
        pleadHear: '',
        registerState: '',
        powerId: '',
        lawsId: '',
        lawdetailId: '',
        powerName: '',
        lawName: '',
        lawTiaoName: ''
      },
      cardList: [],
      imgSize : {     //控制导出的word图片大小
          autographOne: [120, 35],
          autographTwo: [120, 35],
          autographDept: [120, 35],
          autographLegal: [120, 35],
          autographOrgan: [120, 35]
      },
      powerList:[],
      lawList:[],
      lawTiaoList: [],
      finalList: []
    }
  },
  created() {
    this.init()
  },
  methods: {
    init() {
      remote('caseSource_Type').then(res => {
        this.caseSourceList = res.data.data
      })
      remote('document_type').then(res => {
        this.cardList = res.data.data;
      })
      getObj(this.id).then((res) => {
        let v = res.data.data;
        let str = JSON.stringify(v);
        let data = JSON.parse(str);
        this.dataForm = res.data.data;
        //查询公共意见
        this.$nextTick(() => {
          this.$refs.publicOpinion.init(this.dataForm.publicOpinion || {});
        })
        //查询法律
        if (data.powerId != null && data.powerId != '') {
          this.handleSelectPower(data.powerId).then(res => {
                if (data.lawsId != null && data.lawsId != '') {
                  this.handleSelectLaw(v.lawsId);
                  if (data.lawdetailId != null && data.lawdetailId != "") {
                    let ids = [];
                    data.lawdetailId.split(",").forEach(o => {
                      ids.push(parseInt(o));
                    })
                    this.dataForm.lawdetailId = ids;
                  }
                }
              }
          );
        }
      });
    },
    dataFormSubmit(type) {
      this.$refs['dataForm'].validate((valid) => {
        if (valid) {
          let obj = this;
          if ("1" == type) {
            this.$confirm('保存为定稿将不能修改，是否继续？', '提示', {
              confirmButtonText: '是',
              cancelButtonText: '否',
              type: 'warning'
            }).then(function () {
              obj.submitLoading = true;
              obj.dataForm.registerState = type;
              obj.dataForm.registerId = obj.id;
              obj.dataForm.processId = obj.processId;
              if (obj.dataForm.lawdetailId != null) {
                obj.dataForm.lawdetailId = obj.dataForm.lawdetailId.toString();
              }
              saveObj(obj.dataForm).then((res) => {
                if (res.data.code == 0) {
                  obj.$message.success("操作成功");
                  obj.cancel();
                  obj.$emit('getDataList');
                }
              })
            })
          } else {
            this.submitLoading = true;
            this.dataForm.registerState = type;
            this.dataForm.registerId = obj.id;
            this.dataForm.processId = this.processId;
            if (this.dataForm.lawdetailId != null) {
              this.dataForm.lawdetailId = this.dataForm.lawdetailId.toString();
            }
            saveObj(this.dataForm).then((res) => {
              if (res.data.code == 0) {
                this.$message.success("操作成功");
                this.cancel();
              }
            })
          }
        }
      })
    },
    //根据输入模糊查询执法清单，只查行政处罚
    querySearchHandle(queryString) {  //模糊搜素
      getPowerList(queryString,'0').then(res => {
        this.powerList = res.data.data
      })
    },
    //选择执法清单之后查询对应的法律
    handleSelectPower(item) {
      return new Promise( (resolve, reject) => {
        this.dataForm.powerId = item;
        getLawByPowerId(item).then(res => {
          this.lawList = []
          this.finalList = res.data.data
          this.finalList.forEach(item => {
            this.lawList.push({
              value: item.lawName,
              id: item.lawId
            })
          })
          resolve();
        })
      })

    },
    //选择法律之后显示法律的条目
    handleSelectLaw(item) {
      this.dataForm.lawsId = item;
      this.lawTiaoList = [];
      this.dataForm.lawdetailId = '';
      this.finalList.forEach(e => {
        if (e.lawId == item) {
          this.lawTiaoList = e.contentArr;
          return;
        }
      })
    },
    cancel() {
      this.$emit('cancel', false)
    },
    cancelWord() {
      this.showView = false;
    },
    viewVord(data) {
      if(data.registerState == null || data.registerState == ""){
        //预览前先进行保存
        data.registerState = '0';
        data.registerId = this.id;
        data.processId = this.processId;
        saveObj(data).then((res) => {
        })
      }
      //↓↓↓↓↓↓以下部分根据具体业务修改↓↓↓↓↓↓
      //格式转换
      let wordData = this.transforData(data);
      //↑↑↑↑↑↑以上部分根据具体业务修改↑↑↑↑↑↑
      let arry = ['autographOne', 'autographTwo', 'autographDept', 'autographLegal', 'autographOrgan']
      this.showView = true;
      this.$nextTick(() => {
        this.$refs.wordInfo.initMore(wordData, "/wordes/xzcfjd.docx",arry, this.imgSize);
      })
    },
    downloadWord(data) {
      if(data.registerState == null || data.registerState == ""){
        //预览前先进行保存
        data.registerState = '0';
        data.registerId = this.id;
        data.processId = this.processId;
        saveObj(data).then((res) => {
        })
      }
      let wordData = this.transforData(data);
        let arry = ['autographOne', 'autographTwo', 'autographDept', 'autographLegal', 'autographOrgan']
        this.$nextTick(() => {
            this.$refs.wordInfo.exportDocMore(wordData, "/wordes/xzcfjd.docx", this.title+'.docx', arry, this.imgSize);
        })
    },
    transforData(obj) {
      let s = JSON.stringify(obj);
      let data = JSON.parse(s);
      if (data.caseDate != '' && data.caseDate != null) {
        data.caseDate = moment(data.caseDate).format('YYYY年MM月DD日');
      }
      let opinion = data.publicOpinion;
      for (let attr in opinion) {
        if (opinion[attr] == null) {
          data[attr] = '';
        } else {
          data[attr] = opinion[attr];
        }
      }
      let str = JSON.stringify(data);
      let jsonData = JSON.parse(str);
      data = jsonData;

      if (data.undertakeDate != '' && data.undertakeDate != null) {
        data.undertakeDate = moment(data.undertakeDate).format('YYYY年MM月DD日');
      } else {
        data.undertakeDate = '  年  月  日'
      }
      if (data.takeDate != '' && data.takeDate != null) {
        data.takeDate = moment(data.takeDate).format('YYYY年MM月DD日');
      } else {
        data.takeDate = '  年  月  日'
      }
      if (data.legalDate != '' && data.legalDate != null) {
        data.legalDate = moment(data.legalDate).format('YYYY年MM月DD日');
      } else {
        data.legalDate = '  年  月  日'
      }
      if (data.organDate != '' && data.organDate != null) {
        data.organDate = moment(data.organDate).format('YYYY年MM月DD日');
      } else {
        data.organDate = '  年  月  日'
      }
      data.opinion = opinion;
      return data;
    }
  }
}
</script>

<style scoped>

</style>
